@@ -3,9 +3,7 @@
 """
 from flask import current_app as app
 
-from mlask import conf
-
 @app.route('/')
 def index():
-	return 'Hello from %s' % conf.SERVICE_NAME
+	return 'Hello from %s' % app.config.SERVICE_NAME
 """
